@@ -23,7 +23,8 @@ class Topic(Robotnik):
     def broadcast(self, msg: Message,
                   routing_key: Optional[str] = None,
                   on_msg_error: AMQPErrorCallback = None) -> None:
+        msg.routing_key = routing_key or msg.routing_key
         self.channel.basic_publish(exchange=self.exchange,
-                                   routing_key=routing_key if routing_key is not None else '',
+                                   routing_key=(routing_key or msg.routing_key or ''),
                                    body=json.dumps(msg.to_dict()))
         log.debug(f'Broadcast: \n{json.dumps(msg.to_dict(), indent=4)}')
